import React, { Component} from 'react';
import { Card, Form, Button } from 'antd';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import TableForm from './TableForm';
import FooterToolbar from '../../../components/FooterToolbar/index';
import { STATUS_NORMAL } from '../../../utils/config';
import { addRowKey } from '../../../utils/utils';

@connect(({ loading, shelves }) => ({
  shelves,
  submitting: loading.models.shelves,
}))
@Form.create()
export default class ShelvesEdit extends Component {
  constructor(props) {
    super(props);
    const { location } = props;
    const { state } = location;
    const { merchantId, pid, productType } = state;
    this.state = {
      pid,
      merchantId,
      productType,
    };
  }
  componentDidMount() {
    const { merchantId, pid } = this.state;
    this.props.dispatch({
      type: 'shelves/fetchItemDetail',
      payload: {
        pid,
        merchantId,
      },
    });
  }
  handleGoodsCreate=(data) => {
    this.props.dispatch({
      type: 'shelves/createItemPrice',
      payload: {
        ...data,
        ...this.state,
        status: STATUS_NORMAL,
      },
    });
  }
  handleGoodsUpdate=(data) => {
    this.props.dispatch({
      type: 'shelves/updateItemPrice',
      payload: data,
    });
  }
  handleGoodsDelete=(data) => {
    this.props.dispatch({
      type: 'shelves/deleteItemPrice',
      payload: data,
    });
  }
  handlePageBack=() => {
    this.props.dispatch(routerRedux.push({
      pathname: '/shelves/package',
      state: this.props.location.state,
    }));
  }
  render() {
    const { submitting, shelves, form } = this.props;
    const { getFieldDecorator } = form;
    const { currentItem } = shelves;
    const { goods, tags } = currentItem;

    return (
      <div>
        <Card title="定价" style={{marginBottom: 16}}>
          {getFieldDecorator('goods', {
            initialValue: addRowKey(goods),
          })(
            <TableForm
              loading={submitting}
              onCreate={this.handleGoodsCreate}
              onUpdate={this.handleGoodsUpdate}
              onDelete={this.handleGoodsDelete}
            />
          )}
        </Card>
        <FooterToolbar style={{ width: '100%' }}>
          <Button
            type="primary"
            onClick={this.handlePageBack}
            style={{ marginRight: 10 }}
          >返回上一页
          </Button>
        </FooterToolbar>
      </div>
    );
  }
}
